@@ -48,26 +48,43 @@ class Tree:
         for prop in ['description', 'treeType', 'treeIsRooted', 'treeBranchLengthUnit']:
             attrib = ''.join('_' + c.lower() if c.isupper() else c for c in prop)
             setattr(self, attrib, row.get(trees.cols[prop].name) if trees.cols[prop] else None)
+        self.trees = trees
 
-    def newick(self, d: typing.Optional[pathlib.Path] = None):
+    def newick_string(self, d: typing.Optional[pathlib.Path] = None) -> str:
         """
+        Retrieve the Newick representation of the tree from the associated tree file.
+
         :param d: Directory where the tree file was saved earlier, using \
         :meth:`pycldf.media.File.save`.
+        :return: Newick representation of the associated tree.
+        """
+        if self.file.id not in self.trees._parsed_files:
+            content = self.file.read(d=d)
+            if self.file.mimetype == 'text/x-nh':
+                self.trees._parsed_files[self.file.id] = {
+                    str(index): nwk for index, nwk in enumerate(
+                        [t.strip() for t in content.split(';') if t.strip()], start=1)}
+            else:
+                assert content.startswith('#NEXUS')
+                self.trees._parsed_files[self.file.id] = {
+                    tree.name: tree.newick_string
+                    for tree in nexus.NexusReader.from_string(content).trees}
+
+        return self.trees._parsed_files[self.file.id][self.name]
+
+    def newick(self,
+               d: typing.Optional[pathlib.Path] = None,
+               strip_comments: bool = False) -> newick.Node:
+        """
+        Retrieve a `newick.Node` instance for the tree from the associated tree file.
+
+        :param d: Directory where the tree file was saved earlier, using \
+        :meth:`pycldf.media.File.save`.
+        :param strip_comments: Flag signaling whether to strip comments enclosed in square \
+        brackets.
         :return: `newick.Node` representing the root of the associated tree.
         """
-        content = self.file.read(d=d)
-        if self.file.mimetype == 'text/x-nh':
-            for index, tree in enumerate(newick.loads(content), start=1):
-                if str(index) == self.name:
-                    return tree
-        else:
-            assert content.startswith('#NEXUS')
-            for tree in nexus.NexusReader.from_string(content).trees:
-                if self.name == tree.name:
-                    if tree.rooted is not None and self.tree_is_rooted is not None:
-                        assert tree.rooted == self.tree_is_rooted, "conflicting rooting info"
-                    return tree.newick_tree
-        raise KeyError('No matching tree found in tree file')
+        return newick.loads(self.newick_string(d=d), strip_comments=strip_comments)[0]
 
 
 class TreeTable(pycldf.ComponentWithValidation):
@@ -82,6 +99,8 @@ class TreeTable(pycldf.ComponentWithValidation):
             prop: self.ds.get((self.table, prop)) for prop in [
                 'id', 'name', 'description', 'mediaReference',
                 'treeIsRooted', 'treeType', 'treeBranchLengthUnit']}
+        # Since reading and parsing tree files is expensive, we cache them.
+        self._parsed_files = {}
 
     def __iter__(self) -> typing.Generator[Tree, None, None]:
         for row in self.table:
@@ -103,10 +122,6 @@ class TreeTable(pycldf.ComponentWithValidation):
                     log=log)
                 success = False
                 nwk = None
-            except AssertionError as e:
-                log_or_raise(str(e), log=log)
-                success = False
-                nwk = None
 
             if nwk:
                 for node in nwk.walk():
